<div class="bg-white p-4 rounded shadow grid grid-cols-1 md:grid-cols-4 gap-4">
    <div>
        <h4 class="font-semibold text-gray-700">Info</h4>
        <p class="text-green-600 font-bold">{{ stats.info }}</p>
    </div>
    <div>
        <h4 class="font-semibold text-gray-700">Warnings</h4>
        <p class="text-yellow-500 font-bold">{{ stats.warnings }}</p>
    </div>
    <div>
        <h4 class="font-semibold text-gray-700">Errors</h4>
        <p class="text-red-600 font-bold">{{ stats.errors }}</p>
    </div>
    <div>
        <h4 class="font-semibold text-gray-700">Critical</h4>
        <p class="text-red-800 font-bold">{{ stats.critical }}</p>
    </div>
</div>
