<aside class="w-64 bg-gray-800 text-white flex-shrink-0 flex flex-col">
  <div class="p-4 text-xl font-bold">Smart Logger</div>
  <nav class="flex-1">
    <a href="/logs/dashboard" class="block px-4 py-2 hover:bg-gray-700">Dashboard</a>
    <a href="/logs/live-logs" class="block px-4 py-2 hover:bg-gray-700">Live Logs</a>
    <a href="/logs/filter_logs" class="block px-4 py-2 hover:bg-gray-700">Filter Logs</a>
  </nav>
  <div class="p-4 border-t border-gray-700">
    <button onclick="logoutUser()" class="w-full bg-red-600 hover:bg-red-700 py-2 rounded">Logout</button>
  </div>
</aside>

