<!-- System Info Row (Bottom) -->
<div class="bg-white p-4 rounded shadow grid grid-cols-1 md:grid-cols-4 gap-4 mt-6">
  <div>
    <h4 class="font-semibold">CPU</h4>
    <p>{{ system.cpu }}</p>
  </div>
  <div>
    <h4 class="font-semibold">Memory</h4>
    <p>{{ system.memory }}</p>
  </div>
  <div>
    <h4 class="font-semibold">Disk</h4>
    <p>{{ system.disk }}</p>
  </div>
  <div>
    <h4 class="font-semibold">Uptime</h4>
    <p>{{ system.uptime }}</p>
  </div>
</div>
