<header class="bg-white shadow flex items-center justify-between px-4 py-2">
  <h1 class="text-2xl font-bold text-gray-800">Dashboard</h1>
  <div class="flex items-center space-x-4">
    <span class="text-gray-600">User: Admin</span>
    <button onclick="logoutUser()" class="bg-red-600 hover:bg-red-700 text-white px-3 py-1 rounded">Logout</button>
  </div>
</header>
